@@ -3,8 +3,10 @@
 
 #include "../global.h"
 
-void parser(char **argv);              /* call once */
-int yyparse(void);              /* in parse.c */
+void parser(char **argv);           // call once 
+
+int yyparse();                  /// defined in parse.c
+
 int parser_backend();
 
 
