@@ -1,6 +1,3 @@
-/*#define msg
-*/
-
 #include "symtab.ih"
 
 int symtab_addFunction(ExprType type,   /* 0: function added, */
@@ -19,7 +16,7 @@ int symtab_addFunction(ExprType type,   /* 0: function added, */
     next->address = offset;
 
     if (strcmp("main", next->name) == 0 && (type & e_typeMask))
-        util_semantic("`main(...)' must have 'void' return type");
+        util_semantic(sem_mainNotVoid);
 
     msg("gs_vars.nParams is %u", gs_vars.nParams);
 
