@@ -7,6 +7,7 @@
     
 void symtab_writeGlobals(FILE *bin)
 {
+    msg("BEGIN");
     for (VarInfo *begin = gs_vars.varTab->info, 
                    *end = begin + gs_vars.varTab->nVars;     
             begin != end;
@@ -15,4 +16,5 @@ void symtab_writeGlobals(FILE *bin)
         char type = (char)begin->type & ~e_var;
         util_out(bin, &type, sizeof(char));
     }
+    msg("END");
 }
