@@ -1,5 +1,4 @@
-#define msgx
-
+//#define msgx
 #include "builtin.ih"
 
 static char separator[] = {' ', 0};
