@@ -19,7 +19,9 @@ void    intDestructor(Variable const *lhs);
 void    int_assign(Variable *lhs, Variable const *rhs);
 
 void    int_add(Variable *lhs, Variable const *rhs);
-void    int_sub(Variable *lhs, Variable const *rhs); /* same as intCompare */
+void    int_neq(Variable *lhs, Variable const *rhs);
+void    intCompare(Variable *lhs, Variable const *rhs);
+void    int_sub(Variable *lhs, Variable const *rhs);
 int     int_bool(IntVariable const *lhs);
 
 void    int_assignInt(IntVariable *lhs, int value);
