@@ -9,12 +9,7 @@
 
 void o_neq()
 {
-    Variable rval;
+    virtual_compare();
 
-    copycons(&rval, stack_top());
-
-    stack_pop();
-
-    virtual_compare(stack_top(), &rval);
-    destructor(&rval);
+    int_assignInt(stack_top(), int_value(stack_top()) != 0);
 }
