@@ -17,7 +17,7 @@
 
 void o_sm ()
 {
-    o_neq();
+    virtual_compare();
 
     int_assignInt(stack_top(), int_value(stack_top()) < 0);
 }
