@@ -21,7 +21,7 @@ void        virtual_assign(Variable *lhs, Variable const *rhs);
 int         virtual_bool(Variable const *var);  /* var to bool value */
 void        virtual_add(Variable *lhs, Variable const *rhs);
 void        virtual_sub(Variable *lhs, Variable const *rhs);
-void        virtual_compare(Variable *lhs, Variable const *rhs);
+void        virtual_compare();
 
 
 #endif
