@@ -1,6 +1,4 @@
-/*
-#define msg
-*/
+//#define msgx
 
 #include "icmake.ih"
 
