@@ -16,7 +16,7 @@
         decreased by {\em popfile()}) indicates that the file stack is empty.
 */
 
-#define msgx
+//#define msgx
 
 #include "icm-pp.ih"
 
