@@ -1,5 +1,4 @@
-#define msgx
-
+//#define msgx
 
 #include "out.ih"
 
