@@ -1,4 +1,4 @@
-#define msgx
+//#define msgx
 #include "out.ih"
 
 void out_space()
