@@ -1,4 +1,4 @@
-#define msgx
+//#define msgx
 #include "parser.ih"
 
 void p_saveYYtext()
