@@ -1,4 +1,4 @@
-#define msgx
+//#define msgx
 #include "state.ih"
 
 void state_pop(unsigned linenr)
