@@ -4,10 +4,8 @@
     for NON-MSDOS systems ONLY
 
     Arguments:
-        path:   buffer to contain the combined name; length _MAX_PATH
+        path:   buffer to contain the combined name; length MAX_PATHLEN
                 this is NOT checked
-
-        drive:  pointer to drive specifier; ignored
         dir:    directory string, can be NULL or empty ("");
                 if not-empty, may have a trailing DIRSEP character
         fname:  basename string, can be NULL or empty ("")
@@ -16,18 +14,14 @@
 
 */
 
-#include <stdio.h>
-#include <string.h>
-#include "icm.h"
-#include "icrssdef.h"
+#include "rss.ih"
 
-static char
-    dot[] = ".";
+static char dot[] = ".";
 
-void _makepath(char * path,
-    const char * drive, const char * dir, const char * fname, const char * ext)
+void rss_makePath(char *path, char const *dir, char const *fname, 
+                                                char const *ext)
 {
-    path[0] = '\x0';                        /*  prepare for strcats */
+    path[0] = 0;                            /*  prepare for strcats */
 
     if (dir && dir[0])
     {
@@ -35,10 +29,10 @@ void _makepath(char * path,
 
         if (dir[strlen(dir) - 1] != DIRSEP)
         {
-            size_t l;
+            unsigned l;
 
             path[l = strlen(path)] = DIRSEP;
-            path[++l] = '\x0';              /*  make it an asciiz   */
+            path[++l] = 0;              /*  make it an asciiz   */
         }
     }
 
@@ -53,3 +47,8 @@ void _makepath(char * path,
         strcat(path, ext);
     }
 }
+
+
+
+
+
